exceptiontools.SpacingError
===========================

.. abjad-lineage:: abjad.tools.exceptiontools.SpacingError.SpacingError

.. autoclass:: abjad.tools.exceptiontools.SpacingError.SpacingError
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.SpacingError.SpacingError.__delattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.SpacingError.SpacingError.__getitem__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.SpacingError.SpacingError.__getslice__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.SpacingError.SpacingError.__repr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.SpacingError.SpacingError.__setattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.SpacingError.SpacingError.__setstate__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.SpacingError.SpacingError.__str__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.SpacingError.SpacingError.__unicode__
   :noindex:
